@@ -16,6 +16,7 @@
  * <http://www.gnu.org/licenses/>.
  */
 
+#include "config.h"
 #include "babl-internal.h"
 #include "babl-db.h"
 #include <string.h>
@@ -127,4 +128,4 @@ babl_component_new (void *first_arg,
   return babl;
 }
 
-BABL_CLASS (component)
+BABL_CLASS_IMPLEMENT (component)
