@@ -17,6 +17,7 @@
  */
 
 
+#include "config.h"
 #include <string.h>
 #include <stdarg.h>
 #include <math.h>
@@ -79,7 +80,7 @@ conversion_new (const char    *name,
           }
         else if (planar)
           {
-            babl_fatal ("planar conversions not supported for %ssupported",
+            babl_fatal ("planar conversions not supported for %s",
                         babl_class_name (source->class_type));
           }
         break;
@@ -114,19 +115,19 @@ conversion_new (const char    *name,
     {
       Babl *src_format = NULL;
       Babl *dst_format = NULL;
-      if (BABL (babl->conversion.source) == babl_model_id (BABL_RGBA))
+      if (BABL (babl->conversion.source) == babl_model_from_id (BABL_RGBA))
         {
-          src_format = babl_format_id (BABL_RGBA_DOUBLE);
+          src_format = babl_format_from_id (BABL_RGBA_DOUBLE);
           dst_format = babl_format_with_model_as_type (
             BABL (babl->conversion.destination),
-            babl_type_id (BABL_DOUBLE));
+            babl_type_from_id (BABL_DOUBLE));
         }
-      else if (BABL (babl->conversion.destination) == babl_model_id (BABL_RGBA))
+      else if (BABL (babl->conversion.destination) == babl_model_from_id (BABL_RGBA))
         {
           src_format = babl_format_with_model_as_type (
             BABL (babl->conversion.source),
-            babl_type_id (BABL_DOUBLE));
-          dst_format = babl_format_id (BABL_RGBA_DOUBLE);
+            babl_type_from_id (BABL_DOUBLE));
+          dst_format = babl_format_from_id (BABL_RGBA_DOUBLE);
         }
       else
         {
@@ -189,6 +190,8 @@ babl_conversion_new (void *first_arg,
   Babl          *source;
   Babl          *destination;
 
+  char          *name;
+
   va_start (varg, first_arg);
   source      = (Babl *) arg;
   destination = va_arg (varg, Babl *);
@@ -257,18 +260,28 @@ babl_conversion_new (void *first_arg,
     {
       type = BABL_CONVERSION_PLANAR;
     }
-  babl = conversion_new (create_name (source, destination, type),
-                         id, source, destination, linear, plane, planar);
 
-  {
-    Babl *ret = babl_db_insert (db, babl);
-    if (ret != babl)
-      babl_free (babl);
-    else
-      babl_add_ptr_to_list ((void ***) ((Babl *) &(source->type.from)), babl);
+  name = create_name (source, destination, type);
 
-    return ret;
-  }
+  babl = babl_db_exist (db, id, name);
+  if (babl)
+    {
+      /* There is an instance already registered by the required id/name,
+       * returning the preexistent one instead.
+       */
+      return babl;
+    }
+
+  babl = conversion_new (name, id, source, destination, linear, plane, planar);
+
+  /* Since there is not an already registered instance by the required
+   * id/name, inserting newly created class into database.
+   */
+  babl_db_insert (db, babl);
+  if (!source->type.from_list)
+    source->type.from_list = babl_list_init_with_size (BABL_CONVERSIONS);
+  babl_list_insert_last (source->type.from_list, babl);
+  return babl;
 }
 
 static long
@@ -464,6 +477,11 @@ babl_conversion_error (BablConversion *conversion)
   if (!conversion)
     return 0.0;
 
+  if (conversion->error != -1.0)  /* double conversion against a set value should work */
+    {
+      return conversion->error;
+    }
+
   fmt_source      = BABL (conversion->source);
   fmt_destination = BABL (conversion->destination);
 
@@ -486,10 +504,6 @@ babl_conversion_error (BablConversion *conversion)
     {
       conversion->error = 0.000042;
     }
-  if (conversion->error != -1.0)  /* double conversion against a set value should work */
-    {
-      return conversion->error;
-    }
 
   test = test_create ();
 
@@ -537,9 +551,9 @@ babl_conversion_error (BablConversion *conversion)
   babl_free (test);
 
   conversion->error = error;
-  conversion->cost  = (ticks_end - ticks_start) * 10 + 1;
+  conversion->cost  = babl_process_cost (ticks_start, ticks_end);
 
   return error;
 }
 
-BABL_CLASS_TEMPLATE (conversion)
+BABL_CLASS_IMPLEMENT (conversion)
