@@ -16,6 +16,7 @@
  * <http://www.gnu.org/licenses/>.
  */
 
+#include "config.h"
 #include <string.h>
 #include <stdarg.h>
 #include <math.h>
@@ -194,7 +195,7 @@ babl_format_new (void *first_arg,
   BablType      *type      [BABL_MAX_COMPONENTS];
 
   BablSampling  *current_sampling = (BablSampling *) babl_sampling (1, 1);
-  BablType      *current_type     = (BablType *) babl_type_id (BABL_DOUBLE);
+  BablType      *current_type     = (BablType *) babl_type_from_id (BABL_DOUBLE);
   char          *name             = NULL;
   void          *arg              = first_arg;
 
@@ -328,6 +329,58 @@ babl_formats_count (void)
   return babl_db_count (db);
 }
 
+int
+babl_format_has_alpha (const Babl *format)
+{
+  int n = babl_format_get_n_components (format);
+  int i;
+
+  for (i = 0; i < n; i++)
+    {
+      if (format->format.component[i]->alpha)
+        {
+          return 1;
+        }
+    }
+
+  return 0;
+}
+
+int
+babl_format_get_bytes_per_pixel (const Babl *format)
+{
+  if (format->class_type == BABL_FORMAT)
+    {
+      return format->format.bytes_per_pixel;
+    }
+
+  return 0;
+}
+
+int
+babl_format_get_n_components (const Babl *format)
+{
+  if (format->class_type == BABL_FORMAT)
+    {
+      return format->format.components;
+    }
+
+  return 0;
+}
+
+Babl *
+babl_format_get_type (const Babl *format,
+                      int         component_index)
+{
+  if (format->class_type == BABL_FORMAT &&
+      component_index >= 0 &&
+      component_index < format->format.components)
+    {
+      return (Babl *)format->format.type[component_index];
+    }
+
+  return NULL;
+}
 
 Babl *
 babl_format_with_model_as_type (Babl *model,
@@ -436,4 +489,4 @@ babl_format_loss (Babl *babl)
   return loss;
 }
 
-BABL_CLASS (format)
+BABL_CLASS_IMPLEMENT (format)
