@@ -16,6 +16,7 @@
  * <http://www.gnu.org/licenses/>.
  */
 
+#include "config.h"
 #include <stdlib.h>
 #include "babl-internal.h"
 
@@ -132,7 +133,7 @@ babl_internal_destroy (void)
 
 
 const char *
-babl_name (const Babl *babl)
+babl_get_name (const Babl *babl)
 {
   babl_assert (BABL_IS_BABL (babl));
   return babl->instance.name;
