@@ -19,12 +19,15 @@
 #ifndef _BABL_INTERNAL_H
 #define _BABL_INTERNAL_H
 
+#ifndef BABL_LIBRARY
+#error "config.h must be included prior to babl-internal.h"
+#endif
+
 #ifdef _BABL_H
 #error babl-internal.h included after babl.h
 #endif
 
 #define BABL_MAX_COMPONENTS       32
-#define BABL_HARD_MAX_PATH_LENGTH  8
 #define BABL_CONVERSIONS           5
 
 #include <stdlib.h>
@@ -37,8 +40,9 @@
 #include "babl.h"
 #define _BABL_INTERNAL_H
 
-#include "config.h"
-
+#include "babl-class.h"
+#include "babl-classes.h"
+#include "babl-introspect.h"
 #include "babl-list.h"
 #include "babl-hash-table.h"
 #include "babl-db.h"
@@ -60,7 +64,7 @@
 
 
 
-Babl * babl_conversion_find       (const void     *source,
+Babl *   babl_conversion_find           (const void     *source,
                                          const void     *destination);
 double   babl_conversion_error          (BablConversion *conversion);
 long     babl_conversion_cost           (BablConversion *conversion);
@@ -110,10 +114,10 @@ void     babl_die                       (void);
 int      babl_sanity                    (void);
 
 void     babl_core_init                 (void);
-Babl   * babl_format_with_model_as_type (Babl *model,
-                                         Babl *type);
-int      babl_formats_count             (void);  /* should maybe be templated? */
-int      babl_type_is_symmetric         (Babl *babl);
+Babl   * babl_format_with_model_as_type (Babl           *model,
+                                         Babl           *type);
+int      babl_formats_count             (void);                                     /* should maybe be templated? */
+int      babl_type_is_symmetric         (Babl           *babl);
 
 /* FIXME: nasty,. including the symbol even in files where it is
  * not needed,. and a dummy function to use it in those cases
@@ -158,21 +162,70 @@ real_babl_log (const char *file,
   hack_hack ();
 }
 
+/* Provide a string identifying the current function, non-concatenatable */
+#ifndef G_STRFUNC
+#if defined (__GNUC__)
+#  define G_STRFUNC     ((const char*) (__PRETTY_FUNCTION__))
+#elif defined (G_HAVE_ISO_VARARGS)
+#  define G_STRFUNC     ((const char*) (__func__))
+#else
+#  define G_STRFUNC     ((const char*) ("???"))
+#endif
+#endif
+
+#if defined(__cplusplus) && defined(BABL_ISO_CXX_VARIADIC_MACROS)
+#  define BABL_ISO_VARIADIC_MACROS 1
+#endif
+
+#if defined(BABL_ISO_VARIADIC_MACROS)
+
+#define babl_log(...)                                       \
+  real_babl_log(__FILE__, __LINE__, G_STRFUNC, __VA_ARGS__)
+
+#define babl_fatal(...) do{                         	    \
+  real_babl_log(__FILE__, __LINE__, G_STRFUNC, __VA_ARGS__); \
+  babl_die();}                                              \
+while(0)
+
+#elif defined(BABL_GNUC_VARIADIC_MACROS)
+
 #define babl_log(args...)                               \
-  real_babl_log(__FILE__, __LINE__, __func__, args)
+  real_babl_log(__FILE__, __LINE__, G_STRFUNC, args)
 
 #define babl_fatal(args...) do{                         \
-  real_babl_log(__FILE__, __LINE__, __func__, args);\
+  real_babl_log(__FILE__, __LINE__, G_STRFUNC, args);    \
   babl_die();}                                          \
 while(0)
 
+#else
 
-#define babl_assert(expr) do{ \
-  if(!(expr))                 \
-    {                         \
-      babl_fatal("Eeeeek");   \
-      assert(expr);           \
-    }                         \
+static inline void
+babl_log (const char *format, ...)
+{
+  va_list args;
+  va_start (args, format);
+  real_babl_log (__FILE__, __LINE__, G_STRFUNC, format, args);
+  va_end (args);
+}
+static inline void
+babl_fatal (const char *format, ...)
+{
+  va_list args;
+  va_start (args, format);
+  real_babl_log (__FILE__, __LINE__, G_STRFUNC, format, args);
+  va_end (args);
+  babl_die();
+}
+
+#endif
+
+
+#define babl_assert(expr) do{                              \
+  if(!(expr))                                              \
+    {                                                      \
+      real_babl_log(__FILE__, __LINE__, G_STRFUNC, "Eeeeek! Assertion failed: `" #expr "`"); \
+      assert(expr);                                        \
+    }                                                      \
 }while(0)
 /***** LOGGER (end)**/
 
@@ -210,9 +263,9 @@ void         babl_internal_destroy (void);
  * to be kept in sync with the C files.
  */
 
-#define BABL_CLASS_MINIMAL(klass)                             \
+#define BABL_CLASS_MINIMAL_IMPLEMENT(klass)                   \
 void                                                          \
-babl_##klass##_init (void)                                    \
+babl_##klass##_class_init (void)                              \
 {                                                             \
   BABL_PRE_INIT_HOOK;                                         \
   if (!db)                                                    \
@@ -221,7 +274,7 @@ babl_##klass##_init (void)                                    \
 }                                                             \
                                                               \
 void                                                          \
-babl_##klass##_destroy (void)                                 \
+babl_##klass##_class_destroy (void)                           \
 {                                                             \
   BABL_DESTROY_PRE_HOOK;                                      \
   babl_db_each (db,each_babl_##klass##_destroy, NULL);        \
@@ -230,14 +283,14 @@ babl_##klass##_destroy (void)                                 \
 }                                                             \
                                                               \
 void                                                          \
-babl_##klass##_each (BablEachFunction  each_fun,              \
-                     void             *user_data)             \
+babl_##klass##_class_for_each (BablEachFunction  each_fun,    \
+                               void             *user_data)   \
 {                                                             \
   babl_db_each (db, each_fun, user_data);                     \
 }                                                             \
 
-#define BABL_CLASS(klass)                                     \
-BABL_CLASS_MINIMAL(klass)                                     \
+#define BABL_CLASS_IMPLEMENT(klass)                           \
+BABL_CLASS_MINIMAL_IMPLEMENT(klass)                           \
                                                               \
 Babl *                                                        \
 babl_##klass (const char *name)                               \
@@ -246,25 +299,25 @@ babl_##klass (const char *name)                               \
                                                               \
   if (babl_hmpf_on_name_lookups)                              \
     {                                                         \
-      babl_log ("%s(\"%s\"): hmpf!", __func__, name);         \
+      babl_log ("%s(\"%s\"): hmpf!", G_STRFUNC, name);        \
     }                                                         \
   babl = babl_db_exist_by_name (db, name);                    \
                                                               \
   if (!babl)                                                  \
     {                                                         \
-      babl_fatal ("%s(\"%s\"): not found", __func__, name);   \
+      babl_fatal ("%s(\"%s\"): not found", G_STRFUNC, name);  \
     }                                                         \
   return babl;                                                \
 }                                                             \
                                                               \
 Babl *                                                        \
-babl_##klass##_id (int id)                                    \
+babl_##klass##_from_id (int id)                               \
 {                                                             \
   Babl *babl;                                                 \
   babl = babl_db_exist_by_id (db, id);                        \
   if (!babl)                                                  \
     {                                                         \
-      babl_fatal ("%s(%i): not found", __func__, id);         \
+      babl_fatal ("%s(%i): not found", G_STRFUNC, id);        \
     }                                                         \
   return babl;                                                \
 }
