@@ -16,6 +16,7 @@
  * <http://www.gnu.org/licenses/>.
  */
 
+#include "config.h"
 #include <string.h>
 #include <stdarg.h>
 #include <math.h>
@@ -327,4 +328,4 @@ babl_model_is_symmetric (Babl *babl)
   return symmetric;
 }
 
-BABL_CLASS (model)
+BABL_CLASS_IMPLEMENT (model)
