@@ -19,19 +19,13 @@
 #ifndef _BABL_UTIL_H
 #define _BABL_UTIL_H
 
-#include <math.h>
-
-void   babl_add_ptr_to_list (void       ***list,
-                             void         *new);
-
-void
-babl_list_each (void             **list,
-                BablEachFunction   each_fun,
-                void              *user_data);
-
 long
 babl_ticks     (void);
 
+long
+babl_process_cost (long ticks_start,
+                   long ticks_end);
+
 double
 babl_rel_avg_error (double *imgA,
                     double *imgB,
