@@ -17,6 +17,7 @@
  */
 
 
+#include "config.h"
 #include <math.h>
 #include "babl-internal.h"
 
@@ -91,6 +92,6 @@ main (int    argc,
   babl_init ();
   if (test ())
     return -1;
-  babl_destroy ();
+  babl_exit ();
   return 0;
 }
